local easing = require "easing"
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),

		-- Don't forget to include your character's custom assets!
        Asset( "ANIM", "anim/wik.zip" ),
   	Asset( "ANIM", "anim/wik_skinny.zip"),
   	Asset( "ANIM", "anim/wik_mighty.zip"),
    	Asset("ANIM", "anim/player_wolfgang.zip"),

}
local prefabs = {}

local function applymightiness(inst)

	local percent = inst.components.hunger:GetPercent()
	
	local damage_mult = TUNING.WOLFGANG_ATTACKMULT_NORMAL
	local hunger_rate = TUNING.WOLFGANG_HUNGER_RATE_MULT_NORMAL
	local health_max = TUNING.WOLFGANG_HEALTH_NORMAL
	local scale = 1

	local mighty_scale = 1.5
	local wimpy_scale = .7


	if inst.strength == "mighty" then
		local mighty_start = (TUNING.WOLFGANG_START_MIGHTY_THRESH/TUNING.WOLFGANG_HUNGER)	
		local mighty_percent = math.max(0, (percent - mighty_start) / (1 - mighty_start))
		damage_mult = easing.linear(mighty_percent, TUNING.WOLFGANG_ATTACKMULT_MIGHTY_MIN, TUNING.WOLFGANG_ATTACKMULT_MIGHTY_MAX - TUNING.WOLFGANG_ATTACKMULT_MIGHTY_MIN, 1)
		health_max = easing.linear(mighty_percent, TUNING.WOLFGANG_HEALTH_NORMAL, TUNING.WOLFGANG_HEALTH_MIGHTY - TUNING.WOLFGANG_HEALTH_NORMAL, 1)	
		hunger_rate = easing.linear(mighty_percent, TUNING.WOLFGANG_HUNGER_RATE_MULT_NORMAL, TUNING.WOLFGANG_HUNGER_RATE_MULT_MIGHTY - TUNING.WOLFGANG_HUNGER_RATE_MULT_NORMAL, 1)	
		scale = easing.linear(mighty_percent, 1, mighty_scale - 1, 1)	
	elseif inst.strength == "wimpy" then
		local wimpy_start = (TUNING.WOLFGANG_START_WIMPY_THRESH/TUNING.WOLFGANG_HUNGER)	
		local wimpy_percent = math.min(1, percent/wimpy_start )
		damage_mult = easing.linear(wimpy_percent, TUNING.WOLFGANG_ATTACKMULT_WIMPY_MIN, TUNING.WOLFGANG_ATTACKMULT_WIMPY_MAX - TUNING.WOLFGANG_ATTACKMULT_WIMPY_MIN, 1)
		health_max = easing.linear(wimpy_percent, TUNING.WOLFGANG_HEALTH_WIMPY, TUNING.WOLFGANG_HEALTH_NORMAL - TUNING.WOLFGANG_HEALTH_WIMPY, 1)	
		hunger_rate = easing.linear(wimpy_percent, TUNING.WOLFGANG_HUNGER_RATE_MULT_WIMPY, TUNING.WOLFGANG_HUNGER_RATE_MULT_NORMAL - TUNING.WOLFGANG_HUNGER_RATE_MULT_WIMPY, 1)	
		scale = easing.linear(wimpy_percent, wimpy_scale, 1 - wimpy_scale, 1)	
	end
	
	inst.Transform:SetScale(scale,scale,scale)
	inst.components.hunger:SetRate(hunger_rate*TUNING.WILSON_HUNGER_RATE*1.1)
	inst.components.combat.damagemultiplier = damage_mult

	local health_percent = inst.components.health:GetPercent()
	inst.components.health.maxhealth = health_max
	inst.components.health:SetPercent(health_percent)
	inst.components.health:DoDelta(0, true)

end


local function onhungerchange(inst, data)

	if inst.strength == "mighty" then
		if inst.components.hunger.current < TUNING.WOLFGANG_END_MIGHTY_THRESH then
			inst.strength = "normal"
			inst.components.talker:Say"Me belly shrinked..."
			inst.AnimState:SetBuild("wik")
			inst.sg:PushEvent("powerdown")
			inst.SoundEmitter:PlaySound("dontstarve/characters/wolfgang/shrink_lrgtomed")
			inst.talksoundoverride = "dontstarve/characters/wolfgang/talk_LP"
			inst.hurtsoundoverride = "dontstarve/characters/wolfgang/hurt"
		end
	elseif inst.strength == "wimpy" then
		if inst.components.hunger.current > TUNING.WOLFGANG_END_WIMPY_THRESH then
			inst.strength = "normal"
			inst.components.talker:Say"Me feel good! gaw!"
			inst.AnimState:SetBuild("wik")
			inst.sg:PushEvent("powerup")
			inst.SoundEmitter:PlaySound("dontstarve/characters/wolfgang/grow_smtomed")	
			inst.talksoundoverride = "dontstarve/characters/wolfgang/talk_LP"
			inst.hurtsoundoverride = "dontstarve/characters/wolfgang/hurt"
		end
	else
		if inst.components.hunger.current > TUNING.WOLFGANG_START_MIGHTY_THRESH then
			inst.strength = "mighty"
			inst.components.talker:Say"Me belly full Me strong! *burp*"
			inst.AnimState:SetBuild("wik_mighty")
			inst.sg:PushEvent("powerup")
			inst.SoundEmitter:PlaySound("dontstarve/characters/wolfgang/grow_medtolrg")
			inst.talksoundoverride = "dontstarve/characters/wolfgang/talk_large_LP"
			inst.hurtsoundoverride = "dontstarve/characters/wolfgang/hurt_large"

		elseif inst.components.hunger.current < TUNING.WOLFGANG_START_WIMPY_THRESH then
			inst.strength = "wimpy"
			inst.components.talker:Say"ugh... Me feel so empty..."
			inst.AnimState:SetBuild("wik_skinny")
			inst.sg:PushEvent("powerdown")
			inst.SoundEmitter:PlaySound("dontstarve/characters/wolfgang/shrink_medtosml")
			inst.talksoundoverride = "dontstarve/characters/wolfgang/talk_small_LP"
			inst.hurtsoundoverride = "dontstarve/characters/wolfgang/hurt_small"
		end
	end

	applymightiness(inst)
end



local fn = function(inst)

	inst.components.eater.ignoresspoilage = true
	inst.soundsname = "wolfgang"
	inst.MiniMapEntity:SetIcon( "wilson.png" )

	inst.strength = "normal"

	inst.components.hunger:SetMax(TUNING.WOLFGANG_HUNGER)
	inst.components.hunger.current = TUNING.WOLFGANG_START_HUNGER
	applymightiness(inst)
	
	inst:ListenForEvent("hungerdelta", onhungerchange)

end

STRINGS.CHARACTER_TITLES.wik = "The Lizardman"
STRINGS.CHARACTER_NAMES.wik = "Wicked"
STRINGS.CHARACTER_DESCRIPTIONS.wik = "*Have very strong stomach. maybe too strong.\n*Grow and become stronger depends on hunger.\n*Can't talk smart."
STRINGS.CHARACTER_QUOTES.wik = "\"Me want more food!\""


STRINGS.CHARACTERS.WIK = {}
STRINGS.CHARACTERS.WIK.DESCRIBE = {}

STRINGS.CHARACTERS.WIK.ACTIONFAIL_GENERIC = "Me can not."
STRINGS.CHARACTERS.WIK.ANNOUNCE_ADVENTUREFAIL = "Me will go again. gaw!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_BOOMERANG = "Gargh!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_CHARLIE = "Me can not see anything!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_CHARLIE_ATTACK = "Ouch! Who hit me?"
STRINGS.CHARACTERS.WIK.ANNOUNCE_COLD = "Me shiver... brrr"
STRINGS.CHARACTERS.WIK.ANNOUNCE_CRAFTING_FAIL = "Me did something wrong."
STRINGS.CHARACTERS.WIK.ANNOUNCE_DUSK = "Big bright sky ball wants bye-bye."
STRINGS.CHARACTERS.WIK.ANNOUNCE_EAT =
	{
		GENERIC = "Yummy!",
		PAINFUL = "Owww... Me stomach hurts.",
		SPOILED = "Taste funny but fills me belly.",
		STALE = "Me okay Me belly full.",
	}
STRINGS.CHARACTERS.WIK.ANNOUNCE_ENTER_DARK = "Me blind?"
STRINGS.CHARACTERS.WIK.ANNOUNCE_ENTER_LIGHT = "Me see well."
STRINGS.CHARACTERS.WIK.ANNOUNCE_HOUNDS = "Me hear barking. Must ready fight!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_HUNGRY = "Me stomach make strange sound."
STRINGS.CHARACTERS.WIK.ANNOUNCE_HUNT_BEAST_NEARBY = "Me feel giant meat!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_HUNT_LOST_TRAIL = "Giant meat go away."
STRINGS.CHARACTERS.WIK.ANNOUNCE_INV_FULL = "Me pockets full."
STRINGS.CHARACTERS.WIK.ANNOUNCE_PECKED = "Gaw! Too pointy!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_TORCH_OUT = "Bright flower gone!"
STRINGS.CHARACTERS.WIK.ANNOUNCE_WORMHOLE = "That have very long belly."
STRINGS.CHARACTERS.WIK.BATTLECRY =
	{
		GENERIC = "Me will crush you! Gah!",
		PIG = "Get into me belly, Meat!",
		PREY = "Me will kill it!",
		SPIDER = "Clicky monster! Die!",
		SPIDER_WARRIOR = "Jumping clicky monster, Die!",
	}
STRINGS.CHARACTERS.WIK.COMBAT_QUIT =
	{
		GENERIC = "Me do not care.",
	}
STRINGS.CHARACTERS.WIK.DESCRIBE =
	{
		CAVE_BANANA = "Sweet long food!",
		CAVE_BANANA_COOKED = "More sweet long food!",
		CAVE_BANANA_TREE = "Many sweet long food!",
		ROCKY = "That is too hard!",

		HOUNDSTOOTH="Me have lot of this.",
		ARMORSNURTLESHELL="Very hard cloth.",
		BAT="Flying meat!",
		BATBAT = "Me will bat bat with this bat!",
		BATWING="No more flying meat!",
		BATWING_COOKED="Delicious flying meat!",
		BEDROLL_FURRY="Feel so soft.",
		BUNNYMAN="Don't eat meat? Me don't understand.",
		FLOWER_CAVE="Pretty bright flower.",
		FLOWER_CAVE_DOUBLE="Pretty bright flower.",
		FLOWER_CAVE_TRIPLE="Pretty bright flower.",
		GUANO="Even me cannot eat that bad smelly thing.",
		LANTERN="Carring bright thing.",
		LIGHTBULB="Me don't see any fire in here.",
		MANRABBIT_TAIL="Very soft.",
		MUSHTREE_TALL  ="Very big mushroom!",
		MUSHTREE_MEDIUM="Big bright mushroom.",
		MUSHTREE_SMALL ="Me cannot eat that that is too firm.",
		RABBITHOUSE="Furry meat sleeps.",
		SLURTLE="This makes sticky goo.",
		SLURTLE_SHELLPIECES="Useless broken hard cloth.",
		SLURTLEHAT="Me head not hard enough as this.",
		SLURTLEHOLE="Me used to sleep like this.",
		SLURTLESLIME="Gah, sticky!",
		SNURTLE="Ugh, sticky!",
		SPIDER_HIDER="Me have no hard shell like that.",
		SPIDER_SPITTER="That spit really hurts!",
		SPIDERHOLE="Sticky hole. Me no like that.",
		STALAGMITE="Strange rock.",
		STALAGMITE_FULL="Strange rock.",
		STALAGMITE_LOW="Strange rock.",
		STALAGMITE_MED="Strange rock.",
		STALAGMITE_TALL="Me no care about rocks. Me cannot eat that.",
		STALAGMITE_TALL_FULL="Me no care about rocks. Me cannot eat that.",
		STALAGMITE_TALL_LOW="Me no care about rocks. Me cannot eat that.",
		STALAGMITE_TALL_MED="Me no care about rocks. Me cannot eat that.",
		TURF_FUNGUS="Me walks on this.",
		TURF_MUD="Me walks on this.",
		TURF_SINKHOLE="Me walks on this.",
		TURF_UNDERROCK="Me walks on this.",

		POWCAKE = "Strange food.",		
		CAVE_ENTRANCE = 
		{
			GENERIC="Something under here. Me can feel it!",
			OPEN = "Very big hole here. Me curious.",
		},
        CAVE_EXIT = "So bright! Me eyes hurts!",
		BOOMERANG = "Must careful or me ouch me.",
		MAXWELLPHONOGRAPH = "That creature have weird fur.",
		ABIGAIL = "Pretty ghost but me scared.",
		PIGGUARD = "Very bad meat. Meat ouch me.",
		ADVENTURE_PORTAL = "Strange thing. Me can get out here?",
		AMULET = "Ooh, very shiny and pretty. Me neck wants it.",
		ANIMAL_TRACK = "Big meat left it's trace. Me want to follow!",
		ARMORGRASS = "This weak cloth is very weak.",
		ARMORMARBLE = "This hard cloth too heavy.",
		ARMORWOOD = "Me feel safer with this cloth.",
		ARMOR_SANITY = "Me think this cloth talks me.",
		AXE = "Me will breat tree with this! gah!",
		BABYBEEFALO = "This meat need to get big",
		BANDAGE = "This will stop me ouch.",
		BASALT = "No use big rock.",
		BEARDHAIR = "Me do not have this. If me have this, Me will feel very warm.",
		BEDROLL_STRAW = "Scruffy sleepy thing.",
		BEE =
		{
			GENERIC = "Flying sweet carry thing.",
			HELD = "Me smell sweet smell.",
		},
		BEEBOX =
		{
			GENERIC = "Bring sweet goo! Buzzing fly!",
			READY = "Full of sweet goo. Me want to eat that!",
		},
		BEEFALO =
		{
			FOLLOWER = "Why this meat follow me?",
			GENERIC = "Very hairy very big meat.",
			NAKED = "Looks more delicious with hair bye-bye.",
			SLEEPING = "Gur! This meat make very bad sounds!",
		},
		BEEFALOHAT = "Me look scary with this big horn!",
		BEEFALOWOOL = "Strange cloth. Me no have this.",
		BEEHIVE = "This have sweet juice and ouch stings.",
		BERRIES = "Sweet red thing.",
		BERRYBUSH =
		{
			BARREN = "This small tree no look good.",
			GENERIC = "Many delicious red things. Me want to pick that!",
			PICKED = "No more delicious red thing. Me must wait.",
		},
		BIRDCAGE =
		{
			GENERIC = "Me no live in thing like this anymore!",
			OCCUPIED = "Me know that feeling.",
			SLEEPING = "This feathered meat sleeps very good.",
		},
		BIRDTRAP = "feathered meat, come!",
		BIRD_EGG = "Delicious juice in this ball!",
		BIRD_EGG_COOKED = "Firm juice. Me like this.",
		BISHOP = "That shoots thing really ouch.",
		BLOWDART_FIRE = "Take this pointy ouch! gah!",
		BLUEGEM = "looks like small water but very pretty and firm.",
		BLUEPRINT = "Me no understand word but here is picture.",
		BLUE_CAP = "Weird chewy blue tree.",
		BLUE_CAP_COOKED = "More chewy blue tree.",
		BLUE_MUSHROOM =
		{
			GENERIC = "What is this small chewy tree?",
			INGROUND = "Gah! It hide in the ground!",
			PICKED = "Me can eat this now!",
		},
		BOARDS = "Me can make house with this wood!",
		BUGNET = "Me will catch small flying thigs!",
		BUSHHAT = "Me now plant. *giggles*",
		BUTTER = "Melting delitious!",
		BUTTERFLY =
		{
			GENERIC = "Flying pretty fly.",
			HELD = "Now you are mine, pretty.",
		},
		BUTTERFLYWINGS = "This dust makes me eye ouch.",
		CAMPFIRE =
		{
			EMBERS = "Very small fire. More tree need.",
			GENERIC = "Bright keeps dark run away.",
			HIGH = "Very bright! No go too near.",
			LOW = "Not very bright now.",
			NORMAL = "Dancing bright flower looks very funny.",
			OUT = "Bright gone. Me sad.",
		},
		CANE = "Me can run very fast with this!",
		CARROT = "Sweet chubby root.",
		CAVE_FERN = "That's too dark.",
		CHARCOAL = "When bright flower meets tree.",
		CHESTER = "Me can put things into it's belly and put out. Very strange.",
		CHESTER_EYEBONE =
		{
			GENERIC = "This watch me.",
			WAITING = "Me saw this blink!",
		},
		COOKEDMEAT = "More delicious meat! *slurp*",
		COOKEDMONSTERMEAT = "Smells very good but this hurt my belly.",
		COOKEDSMALLMEAT = "Delicious small meat!",
		CROW =
		{
			GENERIC = "That black flying feathered meat scares me.",
			HELD = "ME got you, Black flying feathered meat!",
		},
		CUTGRASS = "Very little trees will grow back.",
		CUTREEDS = "Very useful small trees.",
		CUTSTONE = "Me made this stone very square.",
		DEERCLOPS = "Big Meat with Very big eye!",
		DEERCLOPS_EYEBALL = "Me have two small this",
		DIRTPILE = "Just some dirt.",
		DIVININGROD =
		{
			COLD = "Me no feel anything too.",
			GENERIC = "Find strange things.",
			HOT = "Very near! ME feel it too!",
			WARM = "Something around here.",
			WARMER = "Closer!",
		},
		EARMUFFHAT = "Me head feels warmer with that long ear meat's cloth.",
		EVERGREEN =
		{
			BURNING = "Very hot! No go near!",
			BURNT = "Bright flower meet that tree.",
			CHOPPED = "Broken tree!",
			GENERIC = "Gah! Me do not eat tree. No tasty.",
		},
		EVERGREEN_SPARSE =
		{
			BURNING = "Very hot! No go near!",
			BURNT = "Bright flower meet that tree.",
			CHOPPED = "Broken tree!",
			GENERIC = "Gah! Me do not eat tree. No tasty.",
		},
		EYEPLANT = "Stop look at me!",
		FARMPLOT =
		{
			GENERIC = "Food will grow here!",
			GROWING = "Food growing! Fast and get into me belly!",
			NEEDSFERTILIZER = "This ground is hungry like me.",
		},
		FEM_PUPPET = "This small thing no moving.",
		FIREFLIES =
		{
			GENERIC = "Bright fly! very pretty",
			HELD = "Me pocket is bright now. He he",
		},
		FIREHOUND = "Hot teeth meat!",
		FIREPIT =
		{
			EMBERS = "Very small fire. More tree need.",
			GENERIC = "Bright keeps dark run away.",
			HIGH = "Very bright! No go too near.",
			LOW = "Not very bright now.",
			NORMAL = "Dancing bright flower looks very funny.",
			OUT = "Bright gone. Me sad.",
		},
		FLINT = "Sharp stone. This can make ouchs.",
		FLOWER = "Pretty, smells good but not very tasty.",
		FLOWERHAT = "Me pretty!",
		FLOWER_EVIL = "Bad pretty makes me belly ouch.",
		FOLIAGE = "No delicious small tree.",
		FROG =
		{
			DEAD = "Me want chubby legs!",
			GENERIC = "Jumping slicky meat.",
			SLEEPING = "Me used to sleep like that.",
		},
		GEARS = "Me don't know what this firm things.",
		GHOST = "Gah, Scary whitey!",
		GOLDNUGGET = "Yellow shiny thing. Very pretty.",
		GRASS =
		{
			BARREN = "No eat very small trees.",
			BURNING = "Bright! good.",
			GENERIC = "No eat very small trees.",
			PICKED = "This grow back really fast!",
		},
		GREEN_CAP = "Weird chewy little green tree.",
		GREEN_CAP_COOKED = "More weird chewy little Green tree.",
		GREEN_MUSHROOM =
		{
			GENERIC = "What is this small chewy tree?",
			INGROUND = "Gah! It hide in the ground!",
			PICKED = "Me can eat this now!",
		},
		GUNPOWDER = "Dangerous dirt? Me no understand.",
		HAMBAT = "Delecious ouch thing. Good.",
		HAMMER = "Gah! Destroy things!",
		HEALINGSALVE = "This can stop my ouchs.",
		HEATROCK =
		{
			COLD = "Too cold! No use.",
			GENERIC = "Hot don't go away in this.",
			HOT = "Hot hot! Me hand hot!",
			WARM = "This make me pocket happy.",
		},
		HOMESIGN = "Me no read things.",
		HONEY = "Very very sweet yellow goo. ME LOVE IT!",
		HONEYCOMB = "So many house!",
		HOUND = "Teeth meat. That bite ouch than me!",
		HOUNDMOUND = "Live here? So stupid.",
		ICEBOX = "Very cold box. Me no like cold.",
		ICEHOUND = "Cold teeth meat!",
		INSANITYROCK =
		{
			ACTIVE = "What is this?",
			INACTIVE = "Me don't know.",
		},
		KILLERBEE =
		{
			GENERIC = "Fly stingies! That very ouch and angry.",
			HELD = "Now me angry!",
		},
		KNIGHT = "No meat but moving? So weird.",
		KOALEFANT_SUMMER = "Big meat! Me want to eat meat!",
		KOALEFANT_WINTER = "Fluffy big meat! Me belly will full.",
		KRAMPUS = "Don't take me stuff!",
		KRAMPUS_SACK = "Many food me can carry!",
		LIGHTNING_ROD =
		{
			CHARGED = "It's sparking. Me scary.",
			GENERIC = "No more zzzap for me!",
		},
		LITTLE_WALRUS = "Small fatty meat.",
		LIVINGLOG = "Me think tree can't move. Me wrong!",
		LOG = "Can't eat tree. Too hard.",
		LUREPLANT = "Meat! ...But smell weird.",
		LUREPLANTBULB = "No more trick for me.",
		MALE_PUPPET = "What is this creature?",
		MANDRAKE =
		{
			DEAD = "Little root friend no more move.",
			GENERIC = "Root friend! Me miss you.",
			PICKED = "Little root friend no more move.",
		},
		MARBLE = "Smooth stone. Who make this?",
		MARBLEPILLAR = "Stupid who made this. This no food.",
		MARBLETREE = "Weird tree.",
		MARSH_BUSH =
		{
			BURNING = "Hot! bright flower come.",
			GENERIC = "Very spiky. me hand hurt.",
			PICKED = "Gah! Me hand so ouch!",
		},
		MARSH_PLANT = "Weird little tree.",
		MARSH_TREE =
		{
			BURNING = "Gah! So hot!",
			BURNT = "Bright flower eat that all.",
			CHOPPED = "Me broke this tree! gao!",
			GENERIC = "That tree no look pretty.",
		},
		MAXWELL = "What you want from me?",
		MAXWELLHEAD = "Very stupid looking face.",
		MAXWELLLIGHT = "Bright flower looks weird in this.",
		MAXWELLLOCK = "Secret?",
		MAXWELLTHRONE = "No comportable me think.",
		MEAT = "Me favorite food! *slurp*",
		MEATRACK =
		{
			DONE = "Chewy meat done! Me will eat that!",
			DRYING = "Grrrr. Me wait so long. Me want to eat that.",
			GENERIC = "Chwey meat is really good.",
		},
		MEAT_DRIED = "Chewy meat. Very delicious!",
		MERM = "Me no like that anymore.",
		MERMHEAD = "...... me sad.",
		MERMHOUSE = "This house better than me old house.",
		MONSTERMEAT = "Even me strong belly can't handle this.",
		MONSTERMEAT_DRIED = "Even me strong belly can't handle this.",
		MOSQUITO =
		{
			GENERIC = "No steel me blood!",
			HELD = "Me think revenge, But this too small.",
		},
		MOUND =
		{
			DUG = "No anything more.",
			GENERIC = "What under there?",
		},
		NIGHTLIGHT = "Bright! me like this.",
		NIGHTMAREFUEL = "This feel very weire.",
		NIGHTSWORD = "Me think this long sharp tooth talks to me.",
		NITRE = "What is special about this rock?",
		ONEMANBAND = "Me like music! Music make me happy.",
		PANDORASCHEST = "What is in it?",
		PANFLUTE = "This music make me very sleppy...",
		PAPYRUS = "Me can write this but me can't read it.",
		PENGUIN = "He he. Walk very funny.",
		PETALS = "Flower pretty but not very food.",
		PETALS_EVIL = "This flower make me head dizzy.",
		PICKAXE = "Me broke rock with this!",
		PIGGYBACK = "Smell like meat, but no eat.",
		PIGHEAD = "Who already eat rest!",
		PIGHOUSE =
		{
			FULL = "Meat in here.",
			GENERIC = "Good house. Me want have one.",
			LIGHTSOUT = "Me want to go in!",
		},
		PIGKING = "That's too big meat my belly can handle.",
		PIGMAN =
		{
			DEAD = "Me win!",
			FOLLOWER = "That meat follow me. What it think?",
			GENERIC = "Walking meat. very delicious.",
			GUARD = "Me can beat that angry meat!",
			WEREPIG = "Gah! Meat show it's true form!",
		},
		PIGTORCH = "Why meat guard this thing?",
		PINECONE = 
		{
		    GENERIC = "Small tree egg. Me come from egg like this too?",
		    PLANTED = "Now tree will big.",
		},
		PITCHFORK = "This look like me teeth! he he.",
		PLANTMEAT = "Meat, but smell different.",
		PLANTMEAT_COOKED = "This still nice meat.",
		PLANT_NORMAL =
		{
			GENERIC = "Little tree food.",
			GROWING = "Grow big fast so me can eat!",
			READY = "Now me can eat!",
		},
		POND = "Many food under water.",
		POOP = "Smell funny. Me no eat this anymore.",
		PURPLEGEM = "Very pretty color...",
		RABBIT =
		{
			GENERIC = "Hoping meat!",
			HELD = "Me catch this small meat. Gah!",
		},
		RABBITHOLE = "Me hand no long enough to pick meat.",
		RAINOMETER = "Me like rain. Me like water.",
		RAZOR = "Very sharp! Me no want lost me finger.",
		REDGEM = "Look like hard flower. Very shiny and pretty.",
		RED_CAP = "Weird chewy little red tree.",
		RED_CAP_COOKED = "More weird chewy little red tree.",
		RED_MUSHROOM =
		{
			GENERIC = "What is this small chewy tree?",
			INGROUND = "Gah! It hide in the ground!",
			PICKED = "Me can eat this now!",
		},
		REEDS =
		{
			BURNING = "Very hot!",
			GENERIC = "Very thin little trees.",
			PICKED = "No more thin trees.",
		},
		RESEARCHLAB = "Me can make some new stuff!",
		RESEARCHLAB2 = "Little hard for me to understand.",
		RESEARCHLAB3 = "What is this? Me head hurts.",
		RESURRECTIONSTATUE = "Why wood smells like meat?",
		RESURRECTIONSTONE = "Something strange smells rock.",
		ROBOT_PUPPET = "No moving thing.",
		ROCK = "Rock! Me no eat this me teeth will ouch.",
		ROCKS = "Rock! Me no eat this me teeth will ouch.",
		ROPE = "Me like this twist thing.",
		ROTTENEGG = "Smells so bad! Even me can't eat!",
		SANITYROCK =
		{
			ACTIVE = "What is this?",
			INACTIVE = "No more working",
		},
		SAPLING =
		{
			BURNING = "Bright flower meet this.",
			GENERIC = "Baby tree!",
			PICKED = "Look so helpless.",
		},
		SEEDS = "Very crunch food.",
		SEWING_KIT = "Me can have some cloth. Me skin not very strong.",
		SHOVEL = "Dig! Dig! Dig!",
		SILK = "Very sticky strings!",
		SKELETON = "Who already eat whole meat.",
		SKULLCHEST = "No more meat.",
		SMALLBIRD =
		{
			GENERIC = "This is too twicky! But very cute.",
			HUNGRY = "You hungry? Me hungry too!",
			STARVING = "Me can share some food. It looks too hungry.",
		},
		SMALLMEAT = "Small meat! Omnomnom.",
		SMALLMEAT_DRIED = "Chewy small meat!",
		SPEAR = "Me will fight with this!",
		SPIDER =
		{
			DEAD = "No more clicky monster. Gaw!",
			GENERIC = "Clicky monster have very bad meat.",
			SLEEPING = "Me sleppy too...",
		},
		SPIDERDEN = "Very sticky house. Me no like that!",
		SPIDEREGGSACK = "Why monster want to live like this?",
		SPIDERGLAND = "This make me ouch go away.",
		SPIDERHAT = "Me now clicky monster! gawaw!!!",
		SPIDERQUEEN = "Even monster have mother.",
		SPIDER_WARRIOR =
		{
			DEAD = "You lose jumpy! Gah!",
			GENERIC = "Jumpy clicky monster. Very ouch.",
			SLEEPING = "Me sleppy too...",
		},
		SPOILED_FOOD = "Ugh, Even me no eat this.",
		STATUEHARP = "What is that stange tree in it's hand?",
		STATUEMAXWELL = "He so ugly. Bleah.",
		STINGER = "That make me too ocuh.",
		STRAWHAT = "Me look stupid with this hat.",
		SUNKBOAT = "No more moving. ha!",
		TALLBIRD = "Tall meat. That poke me very ouch.",
		TALLBIRDEGG = "This egg is little different.",
		TALLBIRDEGG_COOKED = "Smells good!",
		TALLBIRDEGG_CRACKED =
		{
			COLD = "It is too cold. Must make it hot.",
			GENERIC = "Something in this egg!",
			HOT = "Hot!",
			LONG = "More time need. Me can't wait!",
			SHORT = "Me heard some tweek. Maybe it is near!",
		},
		TEENBIRD =
		{
			GENERIC = "This grows very fast. Me want to grow big too!",
			HUNGRY = "Hungry? Me hungry too!",
			STARVING = "Me can share some food. That look so hungry.",
		},
		TELEPORTATO_BASE =
		{
			ACTIVE = "Go somewhere else? Me can't wait!",
			GENERIC = "Me can go somewhere else.",
			LOCKED = "It closed. Gah!",
			PARTIAL = "Need some more thing.",
		},
		TELEPORTATO_BOX = "What's in this? Me can't open.",
		TELEPORTATO_CRANK = "Weird looking stone.",
		TELEPORTATO_POTATO = "Look like food but too hard!",
		TELEPORTATO_RING = "What is this?",
		TENT = "Very nice sleep house! Me always want like this.",
		TENTACLE = "That ouch me very hard.",
		TENTACLESPOTS = "Something hidden here.",
		TENTACLESPIKE = "Very strong bat! Me can fight!",
        TENTACLE_PILLAR = "Gah! very big!",
        TENTACLE_PILLAR_ARM = "Me will destroy this!",
        TENTACLE_GARDEN = "This look so weird.",
		TOPHAT = "Me look so hansome! he he.",
		TORCH = "Now me have little bright flower.",
		TRAP = "Get in here, meat!",
		TRAP_TEETH = "This ground bite! very ouch.",
		TRAP_TEETH_MAXWELL = "Me feet will hurt If me feet meet that ground.",
		TREASURECHEST = "Little box. Me can put things in!",
		TRUNKVEST_SUMMER = "Me feel very warm with this cloth.",
		TRUNKVEST_WINTER = "Very warm very soft. Me feel like fall asleep.",
		TRUNK_COOKED = "Good meat! smells good!",
		TRUNK_SUMMER = "Meat! Me can eat this!",
		TRUNK_WINTER = "fluffy meat. Me can eat this!",
		TWIGS = "This little tree is very useful.",
		UMBRELLA = "No more cold sky water for me!",
		WALL_HAY = "This can stop monsters? Looks too weak.",
		WALL_HAY_ITEM = "This can stop monsters? Looks too weak.",
		WALL_STONE = "Strong wall. Me teeth can't break this!",
		WALL_STONE_ITEM = "Strong wall. Me teeth can't break this!",
		WALL_WOOD = "Me build me house. he he.",
		WALL_WOOD_ITEM = "Me build me house. he he.",
		WALRUS = "Fancy fat meat. Me want to be fancy too!",
		WALRUSHAT = "Ha ha Me look so pretty with this!",
		WALRUS_CAMP =
		{
			EMPTY = "Me smell something was here.",
			GENERIC = "That house look very cold.",
		},
		WALRUS_TUSK = "Even me no have big tooth like this!",
		WASPHIVE = "Angry stings live here.",
		WINTERHAT = "Me head cold no more.",
		WINTEROMETER = "Me can see cold and hot!",
		WORMHOLE =
		{
			GENERIC = "That have very very long belly.",
			OPEN = "Whoa. Me didn't know this so long!",
		},
	}



return MakePlayerCharacter("wik", prefabs, assets, fn)
